@@ -25,14 +25,14 @@ module IceCube
         true
       end
 
-      def validate(step_time, schedule)
-        years = step_time.year - schedule.start_time.year
+      def validate(step_time, start_time)
+        years = step_time.year - start_time.year
         offset = (years % interval).nonzero?
         interval - offset if offset
       end
 
       def build_s(builder)
-        builder.base = interval == 1 ? 'Yearly' : "Every #{interval} years"
+        builder.base = IceCube::I18n.t('ice_cube.each_year', count: interval)
       end
 
       def build_hash(builder)
