@@ -7,34 +7,34 @@ describe IceCube::Schedule do
     rule = IceCube::Rule.daily.day(:monday)
     schedule = IceCube::Schedule.new(Time.now)
     schedule.add_recurrence_rule rule
-    lambda { schedule.first(3) }.should_not raise_error
+    expect { schedule.first(3) }.not_to raise_error
   end
 
   it 'should respond to complex combinations (1)' do
-    start_date = Time.utc(2010, 1, 1)
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = Time.utc(2010, 1, 1)
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.yearly(2).day(:wednesday).month_of_year(:april)
     #check assumptions
     dates = schedule.occurrences(Time.utc(2011, 12, 31)) #two years
-    dates.size.should == 4
+    expect(dates.size).to eq(4)
     dates.each do |date|
-      date.wday.should == 3
-      date.month.should == 4
-      date.year.should == start_date.year #since we're doing every other
+      expect(date.wday).to eq(3)
+      expect(date.month).to eq(4)
+      expect(date.year).to eq(start_time.year) #since we're doing every other
     end
   end
 
   it 'should return an added occurrence time' do
     schedule = IceCube::Schedule.new(t0 = Time.now)
     schedule.add_recurrence_time(t0 + 2)
-    schedule.occurrences(t0 + 50).should == [t0, t0 + 2]
+    expect(schedule.occurrences(t0 + 50)).to eq([t0, t0 + 2])
   end
 
   it 'should not return an occurrence time that is excluded' do
     schedule = IceCube::Schedule.new(t0 = Time.now)
     schedule.add_recurrence_time(t0 + 2)
     schedule.add_exception_time(t0 + 2)
-    schedule.occurrences(t0 + 50).should == [t0]
+    expect(schedule.occurrences(t0 + 50)).to eq([t0])
   end
 
   it 'should return properly with a combination of a recurrence and exception rule' do
@@ -42,163 +42,163 @@ describe IceCube::Schedule do
     schedule.add_recurrence_rule IceCube::Rule.daily # every day
     schedule.add_exception_rule IceCube::Rule.weekly.day(:monday, :tuesday, :wednesday) # except these
     #check assumption - in 2 weeks, we should have 8 days
-    schedule.occurrences(DAY + 13 * IceCube::ONE_DAY).size.should == 8
+    expect(schedule.occurrences(DAY + 13 * IceCube::ONE_DAY).size).to eq(8)
   end
 
   it 'should be able to exclude a certain date from a range' do
-    start_date = Time.local 2012, 3, 1
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = Time.local 2012, 3, 1
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily
-    schedule.add_exception_time(start_date + 1 * IceCube::ONE_DAY) # all days except tomorrow
+    schedule.add_exception_time(start_time + 1 * IceCube::ONE_DAY) # all days except tomorrow
     # check assumption
-    dates = schedule.occurrences(start_date + 13 * IceCube::ONE_DAY) # 2 weeks
-    dates.size.should == 13 # 2 weeks minus 1 day
-    dates.should_not include(start_date + 1 * IceCube::ONE_DAY)
+    dates = schedule.occurrences(start_time + 13 * IceCube::ONE_DAY) # 2 weeks
+    expect(dates.size).to eq(13) # 2 weeks minus 1 day
+    expect(dates).not_to include(start_time + 1 * IceCube::ONE_DAY)
   end
 
-  it 'make a schedule with a start_date not included in a rule, and make sure that count behaves properly' do
-    start_date = WEDNESDAY
-    schedule = IceCube::Schedule.new(start_date)
+  it 'make a schedule with a start_time not included in a rule, and make sure that count behaves properly' do
+    start_time = WEDNESDAY
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.weekly.day(:thursday).count(5)
     dates = schedule.all_occurrences
-    dates.uniq.size.should == 5
-    dates.each { |d| d.wday.should == 4 }
-    dates.should_not include(WEDNESDAY)
+    expect(dates.uniq.size).to eq(5)
+    dates.each { |d| expect(d.wday).to eq(4) }
+    expect(dates).not_to include(WEDNESDAY)
   end
 
-  it 'make a schedule with a start_date included in a rule, and make sure that count behaves properly' do
-    start_date = WEDNESDAY + IceCube::ONE_DAY
-    schedule = IceCube::Schedule.new(start_date)
+  it 'make a schedule with a start_time included in a rule, and make sure that count behaves properly' do
+    start_time = WEDNESDAY + IceCube::ONE_DAY
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.weekly.day(:thursday).count(5)
     dates = schedule.all_occurrences
-    dates.uniq.size.should == 5
-    dates.each { |d| d.wday.should == 4 }
-    dates.should include(WEDNESDAY + IceCube::ONE_DAY)
+    expect(dates.uniq.size).to eq(5)
+    dates.each { |d| expect(d.wday).to eq(4) }
+    expect(dates).to include(WEDNESDAY + IceCube::ONE_DAY)
   end
 
   it 'should work as expected with a second_of_minute rule specified' do
-    start_date = DAY
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = DAY
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.weekly.second_of_minute(30)
-    dates = schedule.occurrences(start_date + 30 * 60)
-    dates.each { |date| date.sec.should == 30 }
+    dates = schedule.occurrences(start_time + 30 * 60)
+    dates.each { |date| expect(date.sec).to eq(30) }
   end
 
   it 'ensure that when count on a rule is set to 0, 0 occurrences come back' do
-    start_date = DAY
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = DAY
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily.count(0)
-    schedule.all_occurrences.should == []
+    expect(schedule.all_occurrences).to eq([])
   end
 
-  it 'should be able to be schedules at 1:st:st and 2:st:st every day' do
-    start_date = Time.utc(2007, 9, 2, 9, 15, 25)
-    schedule = IceCube::Schedule.new(start_date)
+  it 'should be able to schedule at hour 1,2 with start min/sec every day' do
+    start_time = Time.utc(2007, 9, 2, 9, 15, 25)
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily.hour_of_day(1, 2).count(6)
     dates = schedule.all_occurrences
-    dates.should == [Time.utc(2007, 9, 3, 1, 15, 25), Time.utc(2007, 9, 3, 2, 15, 25),
+    expect(dates).to eq([Time.utc(2007, 9, 3, 1, 15, 25), Time.utc(2007, 9, 3, 2, 15, 25),
                      Time.utc(2007, 9, 4, 1, 15, 25), Time.utc(2007, 9, 4, 2, 15, 25),
-                     Time.utc(2007, 9, 5, 1, 15, 25), Time.utc(2007, 9, 5, 2, 15, 25)]
+                     Time.utc(2007, 9, 5, 1, 15, 25), Time.utc(2007, 9, 5, 2, 15, 25)])
   end
 
-  it 'should be able to be schedules at 1:0:st and 2:0:st every day' do
-    start_date = Time.utc(2007, 9, 2, 9, 15, 25)
-    schedule = IceCube::Schedule.new(start_date)
+  it 'should be able to schedule at hour 1,2 at min 0 with start sec every day' do
+    start_time = Time.utc(2007, 9, 2, 9, 15, 25)
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily.hour_of_day(1, 2).minute_of_hour(0).count(6)
     dates = schedule.all_occurrences
-    dates.should == [Time.utc(2007, 9, 3, 1, 0, 25), Time.utc(2007, 9, 3, 2, 0, 25),
+    expect(dates).to eq([Time.utc(2007, 9, 3, 1, 0, 25), Time.utc(2007, 9, 3, 2, 0, 25),
                      Time.utc(2007, 9, 4, 1, 0, 25), Time.utc(2007, 9, 4, 2, 0, 25),
-                     Time.utc(2007, 9, 5, 1, 0, 25), Time.utc(2007, 9, 5, 2, 0, 25)]
+                     Time.utc(2007, 9, 5, 1, 0, 25), Time.utc(2007, 9, 5, 2, 0, 25)])
   end
 
   it 'will only return count# if you specify a count and use .first' do
-    start_date = Time.now
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = Time.now
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily.count(10)
     dates = schedule.first(200)
-    dates.size.should == 10
+    expect(dates.size).to eq(10)
   end
 
   it 'occurs yearly' do
-    start_date = DAY
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = DAY
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.yearly
     dates = schedule.first(10)
     dates.each do |date|
-      date.month.should == start_date.month
-      date.day.should == start_date.day
-      date.hour.should == start_date.hour
-      date.min.should == start_date.min
-      date.sec.should == start_date.sec
+      expect(date.month).to eq(start_time.month)
+      expect(date.day).to eq(start_time.day)
+      expect(date.hour).to eq(start_time.hour)
+      expect(date.min).to eq(start_time.min)
+      expect(date.sec).to eq(start_time.sec)
     end
   end
 
   it 'occurs daily' do
-    start_date = Time.now
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = Time.now
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily
     dates = schedule.first(10)
     dates.each do |date|
-      date.hour.should == start_date.hour
-      date.min.should == start_date.min
-      date.sec.should == start_date.sec
+      expect(date.hour).to eq(start_time.hour)
+      expect(date.min).to eq(start_time.min)
+      expect(date.sec).to eq(start_time.sec)
     end
   end
 
   it 'occurs hourly' do
-    start_date = Time.now
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = Time.now
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.hourly
     dates = schedule.first(10)
     dates.each do |date|
-      date.min.should == start_date.min
-      date.sec.should == start_date.sec
+      expect(date.min).to eq(start_time.min)
+      expect(date.sec).to eq(start_time.sec)
     end
   end
 
   it 'occurs minutely' do
-    start_date = Time.now
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = Time.now
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.minutely
     dates = schedule.first(10)
     dates.each do |date|
-      date.sec.should == start_date.sec
+      expect(date.sec).to eq(start_time.sec)
     end
   end
 
   it 'occurs every second for an hour' do
-    start_date = Time.now
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = Time.now
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.secondly.count(60)
     # build the expectation list
     expectation = []
-    0.upto(59) { |i| expectation << start_date + i }
+    0.upto(59) { |i| expectation << start_time + i }
     # compare with what we get
     dates = schedule.all_occurrences
-    dates.size.should == 60
-    schedule.all_occurrences.should == expectation
+    expect(dates.size).to eq(60)
+    expect(schedule.all_occurrences).to eq(expectation)
   end
 
   it 'perform a every day LOCAL and make sure we get back LOCAL' do
     Time.zone = 'Eastern Time (US & Canada)'
-    start_date = Time.zone.local(2010, 9, 2, 5, 0, 0)
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = Time.zone.local(2010, 9, 2, 5, 0, 0)
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily
     schedule.first(10).each do |d|
-      d.utc?.should == false
-      d.hour.should == 5
-      (d.utc_offset == -5 * IceCube::ONE_HOUR || d.utc_offset == -4 * IceCube::ONE_HOUR).should be_true
+      expect(d.utc?).to eq(false)
+      expect(d.hour).to eq(5)
+      expect(d.utc_offset == -5 * IceCube::ONE_HOUR || d.utc_offset == -4 * IceCube::ONE_HOUR).to be_truthy
     end
   end
 
   it 'perform a every day LOCAL and make sure we get back LOCAL' do
-    start_date = Time.utc(2010, 9, 2, 5, 0, 0)
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = Time.utc(2010, 9, 2, 5, 0, 0)
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily
     schedule.first(10).each do |d|
-      d.utc?.should == true
-      d.utc_offset.should == 0
-      d.hour.should == 5
+      expect(d.utc?).to eq(true)
+      expect(d.utc_offset).to eq(0)
+      expect(d.hour).to eq(5)
     end
   end
 
@@ -206,43 +206,58 @@ describe IceCube::Schedule do
   # verify ice_cube is properly checking until bounds
   it 'works with a until date that is UTC, but the start date is local' do
     Time.zone = 'Eastern Time (US & Canada)'
-    start_date = Time.zone.local(2010, 11, 6, 5, 0, 0)
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = Time.zone.local(2010, 11, 6, 5, 0, 0)
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily.until(Time.utc(2010, 11, 10, 8, 0, 0)) #4 o clocal local
     #check assumptions
     dates = schedule.all_occurrences
-    dates.each { |d| d.utc?.should == false }
-    dates.should == [Time.zone.local(2010, 11, 6, 5, 0, 0),
+    dates.each { |d| expect(d.utc?).to eq(false) }
+    expect(dates).to eq([Time.zone.local(2010, 11, 6, 5, 0, 0),
       Time.zone.local(2010, 11, 7, 5, 0, 0), Time.zone.local(2010, 11, 8, 5, 0, 0),
-      Time.zone.local(2010, 11, 9, 5, 0, 0)]
+      Time.zone.local(2010, 11, 9, 5, 0, 0)])
   end
 
   # here we purposely put a local time that is before the range ends, to
   # verify ice_cube is properly checking until bounds
   it 'works with a until date that is local, but the start date is UTC' do
-    start_date = Time.utc(2010, 11, 6, 5, 0, 0)
+    start_time = Time.utc(2010, 11, 6, 5, 0, 0)
     Time.zone = 'Eastern Time (US & Canada)'
-    schedule = IceCube::Schedule.new(start_date)
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily.until(Time.zone.local(2010, 11, 9, 23, 0, 0)) #4 o UTC time
     #check assumptions
     dates = schedule.all_occurrences
-    dates.each { |d| d.utc?.should == true }
-    dates.should == [Time.utc(2010, 11, 6, 5, 0, 0),
+    dates.each { |d| expect(d.utc?).to eq(true) }
+    expect(dates).to eq([Time.utc(2010, 11, 6, 5, 0, 0),
       Time.utc(2010, 11, 7, 5, 0, 0), Time.utc(2010, 11, 8, 5, 0, 0),
-      Time.utc(2010, 11, 9, 5, 0, 0)]
+      Time.utc(2010, 11, 9, 5, 0, 0)])
+  end
+
+  WORLD_TIME_ZONES.each do |zone|
+    context "in #{zone}", :system_time_zone => zone do
+      it 'works with a until date that is a Date, but the start date is UTC' do
+        start_time = Time.utc(2016, 1, 1, 0, 0, 0)
+        schedule = IceCube::Schedule.new(start_time)
+        schedule.add_recurrence_rule IceCube::Rule.daily.until(Date.new(2016, 1, 2))
+        times = schedule.all_occurrences
+        expect(times).to eq [
+                          Time.utc(2016, 1, 1, 0, 0, 0),
+                          Time.utc(2016, 1, 2, 0, 0, 0)
+                        ]
+      end
+    end
   end
 
   it 'works with a monthly rule iterating on UTC' do
-    start_date = Time.utc(2010, 4, 24, 15, 45, 0)
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = Time.utc(2010, 4, 24, 15, 45, 0)
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.monthly
     dates = schedule.first(10)
     dates.each do |d|
-      d.day.should == 24
-      d.hour.should == 15
-      d.min.should == 45
-      d.sec.should == 0
-      d.utc?.should be_true
+      expect(d.day).to eq(24)
+      expect(d.hour).to eq(15)
+      expect(d.min).to eq(45)
+      expect(d.sec).to eq(0)
+      expect(d.utc?).to be_truthy
     end
   end
 
@@ -251,7 +266,7 @@ describe IceCube::Schedule do
     rules = [IceCube::Rule.daily, IceCube::Rule.monthly, IceCube::Rule.yearly]
     rules.each { |r| schedule.add_recurrence_rule(r) }
     # pull the rules back out of the schedule and compare
-    schedule.rrules.should == rules
+    expect(schedule.rrules).to eq(rules)
   end
 
   it 'can retrieve exrules from a schedule' do
@@ -259,7 +274,7 @@ describe IceCube::Schedule do
     rules = [IceCube::Rule.daily, IceCube::Rule.monthly, IceCube::Rule.yearly]
     rules.each { |r| schedule.add_exception_rule(r) }
     # pull the rules back out of the schedule and compare
-    schedule.exrules.should == rules
+    expect(schedule.exrules).to eq(rules)
   end
 
   it 'can retrieve recurrence times from a schedule' do
@@ -267,7 +282,7 @@ describe IceCube::Schedule do
     times = [Time.now, Time.now + 5, Time.now + 10]
     times.each { |d| schedule.add_recurrence_time(d) }
     # pull the dates back out of the schedule and compare
-    schedule.rtimes.should == times
+    expect(schedule.rtimes).to eq(times)
   end
 
   it 'can retrieve exception_times from a schedule' do
@@ -275,7 +290,7 @@ describe IceCube::Schedule do
     times = [Time.now, Time.now + 5, Time.now + 10]
     times.each { |d| schedule.add_exception_time(d) }
     # pull the dates back out of the schedule and compare
-    schedule.extimes.should == times
+    expect(schedule.extimes).to eq(times)
   end
 
   it 'can reuse the same rule' do
@@ -285,7 +300,7 @@ describe IceCube::Schedule do
     result1 = schedule.first(10)
     rule.day(:monday)
     # check to make sure the change affected the rule
-    schedule.first(10).should_not == result1
+    expect(schedule.first(10)).not_to eq(result1)
   end
 
   it 'ensures that month of year (3) is march' do
@@ -295,7 +310,7 @@ describe IceCube::Schedule do
     schedule2 = IceCube::Schedule.new(DAY)
     schedule2.add_recurrence_rule IceCube::Rule.daily.month_of_year(3)
 
-    schedule.first(10).should == schedule2.first(10)
+    expect(schedule.first(10)).to eq(schedule2.first(10))
   end
 
   it 'ensures that day of week (1) is monday' do
@@ -305,7 +320,7 @@ describe IceCube::Schedule do
     schedule2 = IceCube::Schedule.new(DAY)
     schedule2.add_recurrence_rule IceCube::Rule.daily.day(1)
 
-    schedule.first(10).should == schedule2.first(10)
+    expect(schedule.first(10)).to eq(schedule2.first(10))
   end
 
   it 'should be able to find occurrences between two dates which are both in the future' do
@@ -313,52 +328,42 @@ describe IceCube::Schedule do
     schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily
     dates = schedule.occurrences_between(start_time + IceCube::ONE_DAY * 2, start_time + IceCube::ONE_DAY * 4)
-    dates.should == [start_time + IceCube::ONE_DAY * 2, start_time + IceCube::ONE_DAY * 3, start_time + IceCube::ONE_DAY * 4]
-  end
-
-  it 'should use start date on a bi-weekly recurrence pattern to find the occurrences_between when interval > 1' do
-    start_date = Time.local(2011, 3, 20)
-
-    schedule = IceCube::Schedule.new(start_date)
-    schedule.add_recurrence_rule IceCube::Rule.weekly(2).day(:sunday)
-
-    occurrences = schedule.occurrences_between(Time.local(2012, 7, 7), Time.local(2012, 7, 9))
-    occurrences.should == [Time.local(2012, 7, 8)]
+    expect(dates).to eq([start_time + IceCube::ONE_DAY * 2, start_time + IceCube::ONE_DAY * 3, start_time + IceCube::ONE_DAY * 4])
   end
 
   it 'should be able to tell us when there is at least one occurrence between two dates' do
-    start_date = WEDNESDAY
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = WEDNESDAY
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.weekly.day(:friday)
-    true.should == schedule.occurs_between?(start_date, start_date + IceCube::ONE_DAY * 3)
+    expect(true).to eq(schedule.occurs_between?(start_time, start_time + IceCube::ONE_DAY * 3))
   end
 
   it 'should be able to tell us when there is no occurrence between two dates' do
-    start_date = WEDNESDAY
-    schedule = IceCube::Schedule.new(start_date)
+    start_time = WEDNESDAY
+    schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.weekly.day(:friday)
-    false.should == schedule.occurs_between?(start_date, start_date + IceCube::ONE_DAY)
+    expect(false).to eq(schedule.occurs_between?(start_time, start_time + IceCube::ONE_DAY))
   end
 
-  it 'should be able to get back rdates from a schedule' do
+  it 'should be able to get back rtimes from a schedule' do
     schedule = IceCube::Schedule.new DAY
     schedule.add_recurrence_time DAY
     schedule.add_recurrence_time(DAY + 2)
-    schedule.rtimes.should == [DAY, DAY + 2]
+    expect(schedule.rtimes).to eq([DAY, DAY + 2])
   end
 
   it 'should be able to get back exception times from a schedule' do
     schedule = IceCube::Schedule.new DAY
     schedule.add_exception_time DAY
     schedule.add_exception_time(DAY + 2)
-    schedule.extimes.should == [DAY, DAY + 2]
+    expect(schedule.extimes).to eq([DAY, DAY + 2])
   end
 
   it 'should allow calling of .first on a schedule with no arguments' do
     start_time = Time.now
     schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_time start_time
-    schedule.first.should == start_time
+    expect(schedule.first).to eq(start_time)
   end
 
   it 'should be able to ignore nil dates that are inserted as part of a collection to add_recurrence_time' do
@@ -367,21 +372,21 @@ describe IceCube::Schedule do
     schedule.add_recurrence_time start_time
     schedule.add_recurrence_time start_time + IceCube::ONE_DAY
     schedule.add_recurrence_time nil
-    schedule.all_occurrences.should == [start_time, start_time + IceCube::ONE_DAY]
+    expect(schedule.all_occurrences).to eq([start_time, start_time + IceCube::ONE_DAY])
   end
 
   it 'should be able to use all_occurrences with no rules' do
     start_time = Time.now
     schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_time start_time
-    lambda do
-      schedule.all_occurrences.should == [start_time]
-    end.should_not raise_error
+    expect do
+      expect(schedule.all_occurrences).to eq([start_time])
+    end.not_to raise_error
   end
 
   it 'should use occurs_at? when calling occurring_at? with no duration' do
     schedule = IceCube::Schedule.new
-    schedule.should_receive(:occurs_at?)
+    expect(schedule).to receive(:occurs_at?)
     schedule.occurring_at?(Time.now)
   end
 
@@ -390,7 +395,7 @@ describe IceCube::Schedule do
     start_time = Time.local 2010, 5, 6, 10, 0, 0
     schedule = IceCube::Schedule.new(start_time, :duration => 3600)
     schedule.add_recurrence_rule IceCube::Rule.daily
-    schedule.occurring_at?(Time.local(2010, 5, 6, 10, 30, 0)).should be_true #true
+    expect(schedule.occurring_at?(Time.local(2010, 5, 6, 10, 30, 0))).to be_truthy #true
   end
 
   it 'should be able to specify a duration on a schedule and use occurring_at? on that schedule
@@ -398,8 +403,8 @@ describe IceCube::Schedule do
     start_time = Time.local 2010, 5, 6, 10, 0, 0
     schedule = IceCube::Schedule.new(start_time, :duration => 3600)
     schedule.add_recurrence_rule IceCube::Rule.daily
-    schedule.occurring_at?(Time.local(2010, 5, 6, 9, 59, 0)).should be_false
-    schedule.occurring_at?(Time.local(2010, 5, 6, 11, 0, 0)).should be_false
+    expect(schedule.occurring_at?(Time.local(2010, 5, 6, 9, 59, 0))).to be_falsey
+    expect(schedule.occurring_at?(Time.local(2010, 5, 6, 11, 0, 0))).to be_falsey
   end
 
   it 'should be able to specify a duration on a schedule and use occurring_at? on that schedule
@@ -407,8 +412,8 @@ describe IceCube::Schedule do
     start_time = Time.local 2010, 5, 6, 10, 0, 0
     schedule = IceCube::Schedule.new(start_time, :duration => 3600)
     schedule.add_recurrence_rule IceCube::Rule.daily
-    schedule.occurring_at?(Time.local(2010, 5, 6, 10, 0, 0)).should be_true
-    schedule.occurring_at?(Time.local(2010, 5, 6, 10, 59, 59)).should be_true
+    expect(schedule.occurring_at?(Time.local(2010, 5, 6, 10, 0, 0))).to be_truthy
+    expect(schedule.occurring_at?(Time.local(2010, 5, 6, 10, 59, 59))).to be_truthy
   end
 
   it 'should be able to explicity remove a certain minute from a duration' do
@@ -416,9 +421,9 @@ describe IceCube::Schedule do
     schedule = IceCube::Schedule.new(start_time, :duration => 3600)
     schedule.add_recurrence_rule IceCube::Rule.daily
     schedule.add_exception_time Time.local(2010, 5, 6, 10, 21, 30)
-    schedule.occurring_at?(Time.local(2010, 5, 6, 10, 21, 29)).should be_true
-    schedule.occurring_at?(Time.local(2010, 5, 6, 10, 21, 30)).should be_false
-    schedule.occurring_at?(Time.local(2010, 5, 6, 10, 21, 31)).should be_true
+    expect(schedule.occurring_at?(Time.local(2010, 5, 6, 10, 21, 29))).to be_truthy
+    expect(schedule.occurring_at?(Time.local(2010, 5, 6, 10, 21, 30))).to be_falsey
+    expect(schedule.occurring_at?(Time.local(2010, 5, 6, 10, 21, 31))).to be_truthy
   end
 
   it 'should be able to specify an end time for the schedule' do
@@ -426,7 +431,7 @@ describe IceCube::Schedule do
     end_time = DAY + IceCube::ONE_DAY * 2
     schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily.until(end_time)
-    schedule.all_occurrences.should == [DAY, DAY + 1*IceCube::ONE_DAY, DAY + 2*IceCube::ONE_DAY]
+    expect(schedule.all_occurrences).to eq([DAY, DAY + 1*IceCube::ONE_DAY, DAY + 2*IceCube::ONE_DAY])
   end
 
   it 'should be able to specify an end time for the schedule and only get those on .first' do
@@ -434,11 +439,11 @@ describe IceCube::Schedule do
     # ensure proper response without the end time
     schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily
-    schedule.first(5).should == [DAY, DAY + 1*IceCube::ONE_DAY, DAY + 2*IceCube::ONE_DAY, DAY + 3*IceCube::ONE_DAY, DAY + 4*IceCube::ONE_DAY]
+    expect(schedule.first(5)).to eq([DAY, DAY + 1*IceCube::ONE_DAY, DAY + 2*IceCube::ONE_DAY, DAY + 3*IceCube::ONE_DAY, DAY + 4*IceCube::ONE_DAY])
     # and then ensure that with the end time it stops it at the right day
     schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily.until(DAY + IceCube::ONE_DAY * 2 + 1)
-    schedule.first(5).should == [DAY, DAY + 1 * IceCube::ONE_DAY, DAY + 2 * IceCube::ONE_DAY]
+    expect(schedule.first(5)).to eq([DAY, DAY + 1 * IceCube::ONE_DAY, DAY + 2 * IceCube::ONE_DAY])
   end
 
   it 'should be able to specify an end date and go to/from yaml' do
@@ -447,7 +452,7 @@ describe IceCube::Schedule do
     schedule = IceCube::Schedule.new(start_time, :end_time => end_time)
     schedule.add_recurrence_rule IceCube::Rule.daily
     schedule2 = IceCube::Schedule.from_yaml schedule.to_yaml
-    schedule2.end_time.should == end_time
+    expect(schedule2.end_time).to eq(end_time)
   end
 
   it 'should be able to specify an end date for the schedule and only get those on .occurrences_between' do
@@ -456,7 +461,7 @@ describe IceCube::Schedule do
     schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily.until(end_time)
     expectation = [DAY, DAY + IceCube::ONE_DAY, DAY + 2*IceCube::ONE_DAY]
-    schedule.occurrences_between(start_time - IceCube::ONE_DAY, start_time + 4 * IceCube::ONE_DAY).should == expectation
+    expect(schedule.occurrences_between(start_time - IceCube::ONE_DAY, start_time + 4 * IceCube::ONE_DAY)).to eq(expectation)
   end
 
   it 'should be able to specify an end date for the schedule and only get those on .occurrences' do
@@ -465,7 +470,7 @@ describe IceCube::Schedule do
     schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily.until(end_time)
     expectation = [DAY, DAY + IceCube::ONE_DAY, DAY + 2*IceCube::ONE_DAY]
-    schedule.occurrences(start_time + 4 * IceCube::ONE_DAY).should == expectation
+    expect(schedule.occurrences(start_time + 4 * IceCube::ONE_DAY)).to eq(expectation)
   end
 
   it 'should be able to work with an end date and .occurs_at' do
@@ -473,7 +478,7 @@ describe IceCube::Schedule do
     end_time = DAY + IceCube::ONE_DAY * 2
     schedule = IceCube::Schedule.new(start_time)
     schedule.add_recurrence_rule IceCube::Rule.daily.until(end_time)
-    schedule.occurs_at?(DAY + 4*IceCube::ONE_DAY).should be_false # out of range
+    expect(schedule.occurs_at?(DAY + 4*IceCube::ONE_DAY)).to be_falsey # out of range
   end
 
   it 'should be able to work with an end date and .occurring_at' do
@@ -481,8 +486,8 @@ describe IceCube::Schedule do
     end_time = DAY + IceCube::ONE_DAY * 2
     schedule = IceCube::Schedule.new(start_time, :duration => 20)
     schedule.add_recurrence_rule IceCube::Rule.daily.until(end_time)
-    schedule.occurring_at?((DAY + 2*IceCube::ONE_DAY + 10)).should be_true # in range
-    schedule.occurring_at?((DAY + 4*IceCube::ONE_DAY + 10)).should be_false # out of range
+    expect(schedule.occurring_at?((DAY + 2*IceCube::ONE_DAY + 10))).to be_truthy # in range
+    expect(schedule.occurring_at?((DAY + 4*IceCube::ONE_DAY + 10))).to be_falsey # out of range
   end
 
   it 'should not create an infinite loop crossing over february - github issue 6' do
@@ -494,69 +499,69 @@ describe IceCube::Schedule do
   it 'should be able to exist on the 28th of each month crossing over february - github issue 6a' do
     schedule = IceCube::Schedule.new(Time.local(2010, 1, 28))
     schedule.add_recurrence_rule IceCube::Rule.monthly
-    schedule.first(3).should == [Time.local(2010, 1, 28), Time.local(2010, 2, 28), Time.local(2010, 3, 28)]
+    expect(schedule.first(3)).to eq([Time.local(2010, 1, 28), Time.local(2010, 2, 28), Time.local(2010, 3, 28)])
   end
 
   it 'should be able to exist on the 29th of each month crossing over february - github issue 6a' do
     schedule = IceCube::Schedule.new(Time.zone.local(2010, 1, 29))
     schedule.add_recurrence_rule IceCube::Rule.monthly
-    schedule.first(3).should == [Time.zone.local(2010, 1, 29), Time.zone.local(2010, 2, 28), Time.zone.local(2010, 3, 29)]
+    expect(schedule.first(3)).to eq([Time.zone.local(2010, 1, 29), Time.zone.local(2010, 2, 28), Time.zone.local(2010, 3, 29)])
   end
 
   it 'should be able to exist on the 30th of each month crossing over february - github issue 6a' do
     schedule = IceCube::Schedule.new(Time.zone.local(2010, 1, 30))
     schedule.add_recurrence_rule IceCube::Rule.monthly
-    schedule.first(3).should == [Time.zone.local(2010, 1, 30), Time.zone.local(2010, 2, 28), Time.zone.local(2010, 3, 30)]
+    expect(schedule.first(3)).to eq([Time.zone.local(2010, 1, 30), Time.zone.local(2010, 2, 28), Time.zone.local(2010, 3, 30)])
   end
 
   it 'should be able to exist ont he 31st of each month crossing over february - github issue 6a' do
     schedule = IceCube::Schedule.new(Time.zone.local(2010, 1, 31))
     schedule.add_recurrence_rule IceCube::Rule.monthly
-    schedule.first(3).should == [Time.zone.local(2010, 1, 31), Time.zone.local(2010, 2, 28), Time.zone.local(2010, 3, 31)]
+    expect(schedule.first(3)).to eq([Time.zone.local(2010, 1, 31), Time.zone.local(2010, 2, 28), Time.zone.local(2010, 3, 31)])
   end
 
   it 'should deal with a yearly rule that has februaries with different mdays' do
     schedule = IceCube::Schedule.new(Time.local(2008, 2, 29))
     schedule.add_recurrence_rule IceCube::Rule.yearly
-    schedule.first(3).should == [Time.local(2008, 2, 29), Time.local(2009, 2, 28), Time.local(2010, 2, 28)]
+    expect(schedule.first(3)).to eq([Time.local(2008, 2, 29), Time.local(2009, 2, 28), Time.local(2010, 2, 28)])
   end
 
   it 'should work with every other month even when the day of the month iterating on does not exist' do
     schedule = IceCube::Schedule.new(Time.zone.local(2010, 1, 31))
     schedule.add_recurrence_rule IceCube::Rule.monthly(2)
-    schedule.first(6).should == [Time.zone.local(2010, 1, 31), Time.zone.local(2010, 3, 31), Time.zone.local(2010, 5, 31), Time.zone.local(2010, 7, 31), Time.zone.local(2010, 9, 30), Time.zone.local(2010, 11, 30)]
+    expect(schedule.first(6)).to eq([Time.zone.local(2010, 1, 31), Time.zone.local(2010, 3, 31), Time.zone.local(2010, 5, 31), Time.zone.local(2010, 7, 31), Time.zone.local(2010, 9, 30), Time.zone.local(2010, 11, 30)])
   end
 
   it 'should be able to go into february and stay on the same day' do
     schedule = IceCube::Schedule.new(Time.local(2010, 1, 5))
     schedule.add_recurrence_rule IceCube::Rule.monthly
-    schedule.first(2).should == [Time.local(2010, 1, 5), Time.local(2010, 2, 5)]
+    expect(schedule.first(2)).to eq([Time.local(2010, 1, 5), Time.local(2010, 2, 5)])
   end
 
   it 'should be able to know when to stop with an end date and a rule that misses a few times' do
     schedule = IceCube::Schedule.new(Time.local(2010, 2, 29))
     schedule.add_recurrence_rule IceCube::Rule.yearly.until(Time.local(2010, 10, 30))
-    schedule.first(10).should == [Time.local(2010, 2, 29)]
+    expect(schedule.first(10)).to eq([Time.local(2010, 2, 29)])
   end
 
   it 'should be able to know when to stop with an end date and a rule that misses a few times' do
     schedule = IceCube::Schedule.new(Time.local(2010, 2, 29))
     schedule.add_recurrence_rule IceCube::Rule.yearly.until(Time.local(2010, 10, 30))
-    schedule.first(10).should == [Time.local(2010, 2, 29)]
+    expect(schedule.first(10)).to eq([Time.local(2010, 2, 29)])
   end
 
   it 'should be able to know when to stop with an end date and a rule that misses a few times' do
     schedule = IceCube::Schedule.new(Time.local(2010, 2, 29))
     schedule.add_recurrence_rule IceCube::Rule.yearly.count(1)
-    schedule.first(10).should == [Time.local(2010, 2, 29)]
+    expect(schedule.first(10)).to eq([Time.local(2010, 2, 29)])
   end
 
   it 'should have some convenient aliases' do
     start_time = Time.now
     schedule = IceCube::Schedule.new(start_time)
 
-    schedule.start_time.should == schedule.start_time
-    schedule.end_time.should == schedule.end_time
+    expect(schedule.start_time).to eq(schedule.start_time)
+    expect(schedule.end_time).to eq(schedule.end_time)
   end
 
   it 'should have some convenient alias for rrules' do
@@ -564,7 +569,7 @@ describe IceCube::Schedule do
     daily = IceCube::Rule.daily; monthly = IceCube::Rule.monthly
     schedule.add_recurrence_rule daily
     schedule.rrule monthly
-    schedule.rrules.should == [daily, monthly]
+    expect(schedule.rrules).to eq([daily, monthly])
   end
 
   it 'should have some convenient alias for exrules' do
@@ -572,29 +577,29 @@ describe IceCube::Schedule do
     daily = IceCube::Rule.daily; monthly = IceCube::Rule.monthly
     schedule.add_exception_rule daily
     schedule.exrule monthly
-    schedule.exrules.should == [daily, monthly]
+    expect(schedule.exrules).to eq([daily, monthly])
   end
 
   it 'should have some convenient alias for recurrence_times' do
     schedule = IceCube::Schedule.new(Time.now)
     schedule.add_recurrence_time Time.local(2010, 8, 13)
     schedule.rtime Time.local(2010, 8, 14)
-    schedule.rtimes.should == [Time.local(2010, 8, 13), Time.local(2010, 8, 14)]
+    expect(schedule.rtimes).to eq([Time.local(2010, 8, 13), Time.local(2010, 8, 14)])
   end
 
   it 'should have some convenient alias for extimes' do
     schedule = IceCube::Schedule.new(Time.now)
     schedule.add_exception_time Time.local(2010, 8, 13)
     schedule.extime Time.local(2010, 8, 14)
-    schedule.extimes.should == [Time.local(2010, 8, 13), Time.local(2010, 8, 14)]
+    expect(schedule.extimes).to eq([Time.local(2010, 8, 13), Time.local(2010, 8, 14)])
   end
 
   it 'should be able to have a rule and an exrule' do
     schedule = IceCube::Schedule.new(Time.local(2010, 8, 27, 10))
     schedule.rrule IceCube::Rule.daily
     schedule.exrule IceCube::Rule.daily.day(:friday)
-    schedule.occurs_on?(Date.new(2010, 8, 27)).should be_false
-    schedule.occurs_on?(Date.new(2010, 8, 28)).should be_true
+    expect(schedule.occurs_on?(Date.new(2010, 8, 27))).to be_falsey
+    expect(schedule.occurs_on?(Date.new(2010, 8, 28))).to be_truthy
   end
 
   it 'should always generate the correct number of days for .first' do
@@ -602,63 +607,40 @@ describe IceCube::Schedule do
     r = IceCube::Rule.weekly(3).day(:monday, :wednesday, :friday)
     s.add_recurrence_rule(r)
     # test sizes
-    s.first(3).size.should == 3
-    s.first(4).size.should == 4
-    s.first(5).size.should == 5
-  end
-
-
-
-  it 'should always generate the date based off the start_date_override when specified in from_yaml' do
-    start_date = DAY # zero seconds
-    schedule = IceCube::Schedule.new(start_date)
-    schedule.add_recurrence_rule IceCube::Rule.minutely
-
-    start_date_override = DAY + 20
-
-    schedule2 = IceCube::Schedule.from_yaml(schedule.to_yaml, :start_date_override => start_date_override)
-    dates = schedule2.first(10)
-    dates.each do |date|
-      date.sec.should == start_date_override.sec
-    end
-  end
-
-  it 'should always generate the date based off the start_date_override when specified in from_hash' do
-    start_date = DAY # zero seconds
-    schedule = IceCube::Schedule.new(start_date)
-    schedule.add_recurrence_rule IceCube::Rule.minutely
-
-    start_date_override = DAY + 20
-
-    schedule2 = IceCube::Schedule.from_hash(schedule.to_hash, :start_date_override => start_date_override)
-    dates = schedule2.first(10)
-    dates.each do |date|
-      date.sec.should == start_date_override.sec
-    end
+    expect(s.first(3).size).to eq(3)
+    expect(s.first(4).size).to eq(4)
+    expect(s.first(5).size).to eq(5)
   end
 
   it 'should use current date as start date when invoked with a nil parameter' do
     schedule = IceCube::Schedule.new nil
-    (Time.now - schedule.start_time).should be < 100
+    expect(Time.now - schedule.start_time).to be < 100
   end
 
   it 'should be able to get the occurrence count for a rule' do
     rule = IceCube::Rule.daily.count(5)
-    rule.occurrence_count.should == 5
+    expect(rule.occurrence_count).to eq(5)
   end
 
   it 'should be able to remove a count validation from a rule' do
     rule = IceCube::Rule.daily.count(5)
+    expect(rule.occurrence_count).to eq(5)
+    rule.count(nil)
+    expect(rule.occurrence_count).to be_nil
+  end
+
+  it 'should be able to remove a count validation from a rule' do
+    rule = IceCube::Rule.daily.count(5)
+    expect(rule.to_hash[:count]).to eq(5)
     rule.count nil
-    rule.to_hash.should_not have_key(:count)
-    rule.occurrence_count.should be_nil
+    expect(rule.to_hash[:count]).to be_nil
   end
 
   it 'should be able to remove an until validation from a rule' do
     rule = IceCube::Rule.daily.until(Time.now + IceCube::ONE_DAY)
-    rule.to_hash[:until].should_not be_nil
+    expect(rule.to_hash[:until]).not_to be_nil
     rule.until nil
-    rule.to_hash.should_not have_key(:until)
+    expect(rule.to_hash).not_to have_key(:until)
   end
 
   it 'should not have ridiculous load times for minutely on next_occurrence (from sidetiq)' do
@@ -688,7 +670,7 @@ describe IceCube::Schedule do
       (yield).next_occurrence(Time.now)
     end
     total = Time.now - time
-    total.should be < 0.1
+    expect(total).to be < 0.1
   end
 
 end
